CloneableSecret

Trait CloneableSecret 

pub trait CloneableSecret: Clone + Zeroize { }
Marker trait that opts a secret type into cloning.

No methods — its only purpose is to gate the Clone impl on Fixed<T> and Dynamic<T>. Requires the cloneable feature.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors