pub trait SecureDecoding { }Expand description
Marker trait for types that support secure decoding operations.
Automatically implemented for any type that implements AsRef<str>,
such as &str, String, etc. This enables blanket impls of the
individual decoding traits (FromHexStr, FromBase64UrlStr, etc.).
Like SecureEncoding, this is a marker trait with no methods — it exists
to allow trait bounds and extension methods where relevant.
Requires at least one encoding-* feature to be enabled.