SecureDecoding

Trait SecureDecoding 

pub trait SecureDecoding { }
Marker trait for types that support secure decoding operations.

Automatically implemented for any type that implements AsRef<str>, such as &str, String, etc. This enables blanket impls of the individual decoding traits (FromHexStr, FromBase64UrlStr, etc.).

Like SecureEncoding, this is a marker trait with no methods — it exists to allow trait bounds and extension methods where relevant.

Requires at least one encoding-* feature to be enabled.

Implementors

Source

impl<T: AsRef<str> + ?Sized> SecureDecoding for T

Available on crate features encoding-hex or encoding-base64 or encoding-bech32 or encoding-bech32m only.